==> slayersbeasts-fabric-1.21.1-5.2.0-sources.jar: net/invictusslayer/slayersbeasts/client/model/AntWorkerModel.java <==
package net.invictusslayer.slayersbeasts.client.model;

import net.invictusslayer.slayersbeasts.SlayersBeasts;
import net.invictusslayer.slayersbeasts.client.animation.AntWorkerAnimation;
import net.invictusslayer.slayersbeasts.world.entity.AntWorker;
import net.minecraft.class_2960;
import net.minecraft.class_5597;
import net.minecraft.class_5601;
import net.minecraft.class_5603;
import net.minecraft.class_5605;
import net.minecraft.class_5606;
import net.minecraft.class_5607;
import net.minecraft.class_5609;
import net.minecraft.class_5610;
import net.minecraft.class_630;
import net.minecraft.client.model.geom.builders.*;

public class AntWorkerModel<T extends AntWorker> extends class_5597<T> {
	public static final class_5601 LAYER_LOCATION = new class_5601(class_2960.method_60655(SlayersBeasts.MOD_ID, "ant_worker_model"), "main");
	private final class_630 root;

	public AntWorkerModel(class_630 root) {
		this.root = root;
	}

	public class_630 method_32008() {
		return root;
	}

	public void setupAnim(T entity, float limbSwing, float limbSwingAmount, float ageInTicks, float netHeadYaw, float headPitch) {
		root.method_32088().forEach(class_630::method_41923);
		method_48741(AntWorkerAnimation.WALK, limbSwing, limbSwingAmount, 20, 10);
	}

	public static class_5607 createBodyLayer() {
		class_5609 meshdefinition = new class_5609();
		class_5610 partdefinition = meshdefinition.method_32111();

		class_5610 body = partdefinition.method_32117("body", class_5606.method_32108().method_32101(8, 9).method_32098(-1.0F, -4.0F, -2.0F, 2.0F, 2.0F, 4.0F, new class_5605(0.0F))
				.method_32101(0, 7).method_32098(-1.5F, -4.5F, -5.0F, 3.0F, 3.0F, 3.0F, new class_5605(0.0F))
				.method_32101(0, 0).method_32098(-2.0F, -4.5F, 2.0F, 4.0F, 3.0F, 4.0F, new class_5605(0.0F))
				.method_32101(16, 9).method_32098(-1.0F, -3.75F, 6.0F, 2.0F, 2.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32090(0.0F, 24.0F, 0.0F));

		class_5610 cube_r1 = body.method_32117("cube_r1", class_5606.method_32108().method_32101(0, 0).method_32098(0.0F, -2.0F, -1.0F, 0.0F, 2.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(0.5F, -4.5F, -3.5F, 0.0F, 0.0F, 0.3491F));

		class_5610 cube_r2 = body.method_32117("cube_r2", class_5606.method_32108().method_32101(0, 11).method_32098(0.0F, -2.0F, -1.0F, 0.0F, 2.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(-0.5F, -4.5F, -3.5F, 0.0F, 0.0F, -0.3491F));

		class_5610 leg_left_front = body.method_32117("leg_left_front", class_5606.method_32108().method_32101(16, 4).method_32098(-0.25F, 0.0F, -0.5F, 5.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(1.0F, -3.5F, -1.25F, 0.2618F, 0.3491F, 0.6545F));

		class_5610 leg_left_mid = body.method_32117("leg_left_mid", class_5606.method_32108().method_32101(12, 15).method_32098(-0.25F, 0.0F, -0.5F, 5.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(1.0F, -3.5F, 0.0F, 0.0F, 0.0F, 0.6109F));

		class_5610 leg_left_hind = body.method_32117("leg_left_hind", class_5606.method_32108().method_32101(12, 0).method_32098(-0.25F, 0.0F, -0.5F, 5.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(1.0F, -3.5F, 1.25F, -0.2618F, -0.3491F, 0.6545F));

		class_5610 leg_right_front = body.method_32117("leg_right_front", class_5606.method_32108().method_32101(0, 15).method_32098(-4.75F, 0.0F, -0.5F, 5.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(-1.0F, -3.5F, -1.25F, 0.2618F, -0.3491F, -0.6545F));

		class_5610 leg_right_mid = body.method_32117("leg_right_mid", class_5606.method_32108().method_32101(12, 2).method_32098(-4.75F, 0.0F, -0.5F, 5.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(-1.0F, -3.5F, 0.0F, 0.0F, 0.0F, -0.6109F));

		class_5610 leg_right_hind = body.method_32117("leg_right_hind", class_5606.method_32108().method_32101(9, 7).method_32098(-4.75F, 0.0F, -0.5F, 5.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(-1.0F, -3.5F, 1.25F, -0.2618F, 0.3491F, -0.6545F));

		return class_5607.method_32110(meshdefinition, 32, 32);
	}
}

==> slayersbeasts-fabric-1.21.4-6.2.0-sources.jar: net/invictusslayer/slayersbeasts/client/model/AntWorkerModel.java <==
package net.invictusslayer.slayersbeasts.client.model;

import net.invictusslayer.slayersbeasts.SlayersBeasts;
import net.invictusslayer.slayersbeasts.client.animation.AntWorkerAnimation;
import net.invictusslayer.slayersbeasts.client.state.AntWorkerRenderState;
import net.minecraft.class_2960;
import net.minecraft.class_5601;
import net.minecraft.class_5603;
import net.minecraft.class_5605;
import net.minecraft.class_5606;
import net.minecraft.class_5607;
import net.minecraft.class_5609;
import net.minecraft.class_5610;
import net.minecraft.class_583;
import net.minecraft.class_630;
import net.minecraft.client.model.geom.builders.*;

public class AntWorkerModel extends class_583<AntWorkerRenderState> {
	public static final class_5601 LAYER_LOCATION = new class_5601(class_2960.method_60655(SlayersBeasts.MOD_ID, "ant_worker_model"), "main");

	public AntWorkerModel(class_630 root) {
		super(root);
	}

	public void setupAnim(AntWorkerRenderState state) {
		super.method_2819(state);
		method_62102(AntWorkerAnimation.WALK, state.field_53450, state.field_53451, 20, 10);
	}

	public static class_5607 createBodyLayer() {
		class_5609 meshdefinition = new class_5609();
		class_5610 partdefinition = meshdefinition.method_32111();

		class_5610 body = partdefinition.method_32117("body", class_5606.method_32108().method_32101(8, 9).method_32098(-1.0F, -4.0F, -2.0F, 2.0F, 2.0F, 4.0F, new class_5605(0.0F))
				.method_32101(0, 7).method_32098(-1.5F, -4.5F, -5.0F, 3.0F, 3.0F, 3.0F, new class_5605(0.0F))
				.method_32101(0, 0).method_32098(-2.0F, -4.5F, 2.0F, 4.0F, 3.0F, 4.0F, new class_5605(0.0F))
				.method_32101(16, 9).method_32098(-1.0F, -3.75F, 6.0F, 2.0F, 2.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32090(0.0F, 24.0F, 0.0F));

		class_5610 cube_r1 = body.method_32117("cube_r1", class_5606.method_32108().method_32101(0, 0).method_32098(0.0F, -2.0F, -1.0F, 0.0F, 2.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(0.5F, -4.5F, -3.5F, 0.0F, 0.0F, 0.3491F));

		class_5610 cube_r2 = body.method_32117("cube_r2", class_5606.method_32108().method_32101(0, 11).method_32098(0.0F, -2.0F, -1.0F, 0.0F, 2.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(-0.5F, -4.5F, -3.5F, 0.0F, 0.0F, -0.3491F));

		class_5610 leg_left_front = body.method_32117("leg_left_front", class_5606.method_32108().method_32101(16, 4).method_32098(-0.25F, 0.0F, -0.5F, 5.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(1.0F, -3.5F, -1.25F, 0.2618F, 0.3491F, 0.6545F));

		class_5610 leg_left_mid = body.method_32117("leg_left_mid", class_5606.method_32108().method_32101(12, 15).method_32098(-0.25F, 0.0F, -0.5F, 5.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(1.0F, -3.5F, 0.0F, 0.0F, 0.0F, 0.6109F));

		class_5610 leg_left_hind = body.method_32117("leg_left_hind", class_5606.method_32108().method_32101(12, 0).method_32098(-0.25F, 0.0F, -0.5F, 5.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(1.0F, -3.5F, 1.25F, -0.2618F, -0.3491F, 0.6545F));

		class_5610 leg_right_front = body.method_32117("leg_right_front", class_5606.method_32108().method_32101(0, 15).method_32098(-4.75F, 0.0F, -0.5F, 5.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(-1.0F, -3.5F, -1.25F, 0.2618F, -0.3491F, -0.6545F));

		class_5610 leg_right_mid = body.method_32117("leg_right_mid", class_5606.method_32108().method_32101(12, 2).method_32098(-4.75F, 0.0F, -0.5F, 5.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(-1.0F, -3.5F, 0.0F, 0.0F, 0.0F, -0.6109F));

		class_5610 leg_right_hind = body.method_32117("leg_right_hind", class_5606.method_32108().method_32101(9, 7).method_32098(-4.75F, 0.0F, -0.5F, 5.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(-1.0F, -3.5F, 1.25F, -0.2618F, 0.3491F, -0.6545F));

		return class_5607.method_32110(meshdefinition, 32, 32);
	}
}
